@@ -1,15 +1,15 @@
 //------------------------------------------------------------------------------
 // Project:  arrayfunc
 // Module:   amin_simd_x86.h
-// Purpose:  Find the minimum value in an array.
+// Purpose:  Calculate the amin of values in an array.
 //           This file provides an SIMD version of the functions.
 // Language: C
-// Date:     01-May-2017
-// Ver:      19-Jun-2018.
+// Date:     16-Apr-2019
+// Ver:      24-Jul-2019.
 //
 //------------------------------------------------------------------------------
 //
-//   Copyright 2014 - 2018    Michael Griffin    <m12.griffin@gmail.com>
+//   Copyright 2014 - 2019    Michael Griffin    <m12.griffin@gmail.com>
 //
 //   Licensed under the Apache License, Version 2.0 (the "License");
 //   you may not use this file except in compliance with the License.
@@ -26,13 +26,13 @@
 //------------------------------------------------------------------------------
 
 
-signed char amin_signed_char_simd(Py_ssize_t arraylen, signed char *data);
-unsigned char amin_unsigned_char_simd(Py_ssize_t arraylen, unsigned char *data);
-signed short amin_signed_short_simd(Py_ssize_t arraylen, signed short *data);
-unsigned short amin_unsigned_short_simd(Py_ssize_t arraylen, unsigned short *data);
-signed int amin_signed_int_simd(Py_ssize_t arraylen, signed int *data);
-unsigned int amin_unsigned_int_simd(Py_ssize_t arraylen, unsigned int *data);
-float amin_float_simd(Py_ssize_t arraylen, float *data);
+signed long long amin_signed_char_simd(Py_ssize_t arraylen, signed char *data);
+unsigned long long amin_unsigned_char_simd(Py_ssize_t arraylen, unsigned char *data);
+signed long long amin_signed_short_simd(Py_ssize_t arraylen, signed short *data);
+unsigned long long amin_unsigned_short_simd(Py_ssize_t arraylen, unsigned short *data);
+signed long long amin_signed_int_simd(Py_ssize_t arraylen, signed int *data);
+unsigned long long amin_unsigned_int_simd(Py_ssize_t arraylen, unsigned int *data);
+double amin_float_simd(Py_ssize_t arraylen, float *data);
 double amin_double_simd(Py_ssize_t arraylen, double *data);
 
 
