@@ -7,7 +7,7 @@
 //
 //------------------------------------------------------------------------------
 //
-//   Copyright 2014 - 2018    Michael Griffin    <m12.griffin@gmail.com>
+//   Copyright 2014 - 2019    Michael Griffin    <m12.griffin@gmail.com>
 //
 //   Licensed under the Apache License, Version 2.0 (the "License");
 //   you may not use this file except in compliance with the License.
@@ -39,6 +39,12 @@
 
 #include "arrayparams_comp.h"
 
+#include "simddefs.h"
+
+#ifdef AF_HASSIMD
+#include "lt_simd_x86.h"
+#endif
+
 /*--------------------------------------------------------------------------- */
 
 /*--------------------------------------------------------------------------- */
@@ -49,7 +55,445 @@
    param = The parameter to be applied to each array element.
 */
 // param_arr_num
-char lt_signed_char_1(Py_ssize_t arraylen, signed char *data1, signed char param) {
+char lt_signed_char_1(Py_ssize_t arraylen, int nosimd, signed char *data1, signed char param) {
+
+	// array index counter.
+	Py_ssize_t x;
+
+#ifdef AF_HASSIMD
+	// SIMD version.
+	if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
+		return lt_signed_char_1_simd(arraylen, data1, param);
+	}
+#endif
+
+	for(x = 0; x < arraylen; x++) {
+		if (!(data1[x] < param)) { return 0; }
+	}
+
+	return 1;
+
+}
+
+
+// param_num_arr
+char lt_signed_char_3(Py_ssize_t arraylen, int nosimd, signed char param, signed char *data2) {
+
+	// array index counter.
+	Py_ssize_t x;
+
+#ifdef AF_HASSIMD
+	// SIMD version.
+	if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
+		return lt_signed_char_3_simd(arraylen, param, data2);
+	}
+#endif
+
+	for(x = 0; x < arraylen; x++) {
+		if (!(param < data2[x])) { return 0; }
+	}
+
+	return 1;
+
+}
+
+
+// param_arr_arr
+char lt_signed_char_5(Py_ssize_t arraylen, int nosimd, signed char *data1, signed char *data2) {
+
+	// array index counter.
+	Py_ssize_t x;
+
+#ifdef AF_HASSIMD
+	// SIMD version.
+	if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
+		return lt_signed_char_5_simd(arraylen, data1, data2);
+	}
+#endif
+
+	for(x = 0; x < arraylen; x++) {
+		if (!(data1[x] < data2[x])) { return 0; }
+	}
+
+	return 1;
+
+}
+
+
+/*--------------------------------------------------------------------------- */
+/* The following series of functions reflect the different parameter options possible.
+   arraylen = The length of the data arrays.
+   data1 = The first data array.
+   data2 = The second data array.
+   param = The parameter to be applied to each array element.
+*/
+// param_arr_num
+char lt_unsigned_char_1(Py_ssize_t arraylen, int nosimd, unsigned char *data1, unsigned char param) {
+
+	// array index counter.
+	Py_ssize_t x;
+
+#ifdef AF_HASSIMD
+	// SIMD version.
+	if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
+		return lt_unsigned_char_1_simd(arraylen, data1, param);
+	}
+#endif
+
+	for(x = 0; x < arraylen; x++) {
+		if (!(data1[x] < param)) { return 0; }
+	}
+
+	return 1;
+
+}
+
+
+// param_num_arr
+char lt_unsigned_char_3(Py_ssize_t arraylen, int nosimd, unsigned char param, unsigned char *data2) {
+
+	// array index counter.
+	Py_ssize_t x;
+
+#ifdef AF_HASSIMD
+	// SIMD version.
+	if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
+		return lt_unsigned_char_3_simd(arraylen, param, data2);
+	}
+#endif
+
+	for(x = 0; x < arraylen; x++) {
+		if (!(param < data2[x])) { return 0; }
+	}
+
+	return 1;
+
+}
+
+
+// param_arr_arr
+char lt_unsigned_char_5(Py_ssize_t arraylen, int nosimd, unsigned char *data1, unsigned char *data2) {
+
+	// array index counter.
+	Py_ssize_t x;
+
+#ifdef AF_HASSIMD
+	// SIMD version.
+	if (!nosimd && (arraylen >= (CHARSIMDSIZE * 2))) {
+		return lt_unsigned_char_5_simd(arraylen, data1, data2);
+	}
+#endif
+
+	for(x = 0; x < arraylen; x++) {
+		if (!(data1[x] < data2[x])) { return 0; }
+	}
+
+	return 1;
+
+}
+
+
+/*--------------------------------------------------------------------------- */
+/* The following series of functions reflect the different parameter options possible.
+   arraylen = The length of the data arrays.
+   data1 = The first data array.
+   data2 = The second data array.
+   param = The parameter to be applied to each array element.
+*/
+// param_arr_num
+char lt_signed_short_1(Py_ssize_t arraylen, int nosimd, signed short *data1, signed short param) {
+
+	// array index counter.
+	Py_ssize_t x;
+
+#ifdef AF_HASSIMD
+	// SIMD version.
+	if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
+		return lt_signed_short_1_simd(arraylen, data1, param);
+	}
+#endif
+
+	for(x = 0; x < arraylen; x++) {
+		if (!(data1[x] < param)) { return 0; }
+	}
+
+	return 1;
+
+}
+
+
+// param_num_arr
+char lt_signed_short_3(Py_ssize_t arraylen, int nosimd, signed short param, signed short *data2) {
+
+	// array index counter.
+	Py_ssize_t x;
+
+#ifdef AF_HASSIMD
+	// SIMD version.
+	if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
+		return lt_signed_short_3_simd(arraylen, param, data2);
+	}
+#endif
+
+	for(x = 0; x < arraylen; x++) {
+		if (!(param < data2[x])) { return 0; }
+	}
+
+	return 1;
+
+}
+
+
+// param_arr_arr
+char lt_signed_short_5(Py_ssize_t arraylen, int nosimd, signed short *data1, signed short *data2) {
+
+	// array index counter.
+	Py_ssize_t x;
+
+#ifdef AF_HASSIMD
+	// SIMD version.
+	if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
+		return lt_signed_short_5_simd(arraylen, data1, data2);
+	}
+#endif
+
+	for(x = 0; x < arraylen; x++) {
+		if (!(data1[x] < data2[x])) { return 0; }
+	}
+
+	return 1;
+
+}
+
+
+/*--------------------------------------------------------------------------- */
+/* The following series of functions reflect the different parameter options possible.
+   arraylen = The length of the data arrays.
+   data1 = The first data array.
+   data2 = The second data array.
+   param = The parameter to be applied to each array element.
+*/
+// param_arr_num
+char lt_unsigned_short_1(Py_ssize_t arraylen, int nosimd, unsigned short *data1, unsigned short param) {
+
+	// array index counter.
+	Py_ssize_t x;
+
+#ifdef AF_HASSIMD
+	// SIMD version.
+	if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
+		return lt_unsigned_short_1_simd(arraylen, data1, param);
+	}
+#endif
+
+	for(x = 0; x < arraylen; x++) {
+		if (!(data1[x] < param)) { return 0; }
+	}
+
+	return 1;
+
+}
+
+
+// param_num_arr
+char lt_unsigned_short_3(Py_ssize_t arraylen, int nosimd, unsigned short param, unsigned short *data2) {
+
+	// array index counter.
+	Py_ssize_t x;
+
+#ifdef AF_HASSIMD
+	// SIMD version.
+	if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
+		return lt_unsigned_short_3_simd(arraylen, param, data2);
+	}
+#endif
+
+	for(x = 0; x < arraylen; x++) {
+		if (!(param < data2[x])) { return 0; }
+	}
+
+	return 1;
+
+}
+
+
+// param_arr_arr
+char lt_unsigned_short_5(Py_ssize_t arraylen, int nosimd, unsigned short *data1, unsigned short *data2) {
+
+	// array index counter.
+	Py_ssize_t x;
+
+#ifdef AF_HASSIMD
+	// SIMD version.
+	if (!nosimd && (arraylen >= (SHORTSIMDSIZE * 2))) {
+		return lt_unsigned_short_5_simd(arraylen, data1, data2);
+	}
+#endif
+
+	for(x = 0; x < arraylen; x++) {
+		if (!(data1[x] < data2[x])) { return 0; }
+	}
+
+	return 1;
+
+}
+
+
+/*--------------------------------------------------------------------------- */
+/* The following series of functions reflect the different parameter options possible.
+   arraylen = The length of the data arrays.
+   data1 = The first data array.
+   data2 = The second data array.
+   param = The parameter to be applied to each array element.
+*/
+// param_arr_num
+char lt_signed_int_1(Py_ssize_t arraylen, int nosimd, signed int *data1, signed int param) {
+
+	// array index counter.
+	Py_ssize_t x;
+
+#ifdef AF_HASSIMD
+	// SIMD version.
+	if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
+		return lt_signed_int_1_simd(arraylen, data1, param);
+	}
+#endif
+
+	for(x = 0; x < arraylen; x++) {
+		if (!(data1[x] < param)) { return 0; }
+	}
+
+	return 1;
+
+}
+
+
+// param_num_arr
+char lt_signed_int_3(Py_ssize_t arraylen, int nosimd, signed int param, signed int *data2) {
+
+	// array index counter.
+	Py_ssize_t x;
+
+#ifdef AF_HASSIMD
+	// SIMD version.
+	if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
+		return lt_signed_int_3_simd(arraylen, param, data2);
+	}
+#endif
+
+	for(x = 0; x < arraylen; x++) {
+		if (!(param < data2[x])) { return 0; }
+	}
+
+	return 1;
+
+}
+
+
+// param_arr_arr
+char lt_signed_int_5(Py_ssize_t arraylen, int nosimd, signed int *data1, signed int *data2) {
+
+	// array index counter.
+	Py_ssize_t x;
+
+#ifdef AF_HASSIMD
+	// SIMD version.
+	if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
+		return lt_signed_int_5_simd(arraylen, data1, data2);
+	}
+#endif
+
+	for(x = 0; x < arraylen; x++) {
+		if (!(data1[x] < data2[x])) { return 0; }
+	}
+
+	return 1;
+
+}
+
+
+/*--------------------------------------------------------------------------- */
+/* The following series of functions reflect the different parameter options possible.
+   arraylen = The length of the data arrays.
+   data1 = The first data array.
+   data2 = The second data array.
+   param = The parameter to be applied to each array element.
+*/
+// param_arr_num
+char lt_unsigned_int_1(Py_ssize_t arraylen, int nosimd, unsigned int *data1, unsigned int param) {
+
+	// array index counter.
+	Py_ssize_t x;
+
+#ifdef AF_HASSIMD
+	// SIMD version.
+	if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
+		return lt_unsigned_int_1_simd(arraylen, data1, param);
+	}
+#endif
+
+	for(x = 0; x < arraylen; x++) {
+		if (!(data1[x] < param)) { return 0; }
+	}
+
+	return 1;
+
+}
+
+
+// param_num_arr
+char lt_unsigned_int_3(Py_ssize_t arraylen, int nosimd, unsigned int param, unsigned int *data2) {
+
+	// array index counter.
+	Py_ssize_t x;
+
+#ifdef AF_HASSIMD
+	// SIMD version.
+	if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
+		return lt_unsigned_int_3_simd(arraylen, param, data2);
+	}
+#endif
+
+	for(x = 0; x < arraylen; x++) {
+		if (!(param < data2[x])) { return 0; }
+	}
+
+	return 1;
+
+}
+
+
+// param_arr_arr
+char lt_unsigned_int_5(Py_ssize_t arraylen, int nosimd, unsigned int *data1, unsigned int *data2) {
+
+	// array index counter.
+	Py_ssize_t x;
+
+#ifdef AF_HASSIMD
+	// SIMD version.
+	if (!nosimd && (arraylen >= (INTSIMDSIZE * 2))) {
+		return lt_unsigned_int_5_simd(arraylen, data1, data2);
+	}
+#endif
+
+	for(x = 0; x < arraylen; x++) {
+		if (!(data1[x] < data2[x])) { return 0; }
+	}
+
+	return 1;
+
+}
+
+
+/*--------------------------------------------------------------------------- */
+/* The following series of functions reflect the different parameter options possible.
+   arraylen = The length of the data arrays.
+   data1 = The first data array.
+   data2 = The second data array.
+   param = The parameter to be applied to each array element.
+*/
+// param_arr_num
+char lt_signed_long_1(Py_ssize_t arraylen, int nosimd, signed long *data1, signed long param) {
 
 	// array index counter.
 	Py_ssize_t x;
@@ -64,7 +508,7 @@ char lt_signed_char_1(Py_ssize_t arraylen, signed char *data1, signed char param
 
 
 // param_num_arr
-char lt_signed_char_3(Py_ssize_t arraylen, signed char param, signed char *data2) {
+char lt_signed_long_3(Py_ssize_t arraylen, int nosimd, signed long param, signed long *data2) {
 
 	// array index counter.
 	Py_ssize_t x;
@@ -79,7 +523,7 @@ char lt_signed_char_3(Py_ssize_t arraylen, signed char param, signed char *data2
 
 
 // param_arr_arr
-char lt_signed_char_5(Py_ssize_t arraylen, signed char *data1, signed char *data2) {
+char lt_signed_long_5(Py_ssize_t arraylen, int nosimd, signed long *data1, signed long *data2) {
 
 	// array index counter.
 	Py_ssize_t x;
@@ -101,7 +545,7 @@ char lt_signed_char_5(Py_ssize_t arraylen, signed char *data1, signed char *data
    param = The parameter to be applied to each array element.
 */
 // param_arr_num
-char lt_unsigned_char_1(Py_ssize_t arraylen, unsigned char *data1, unsigned char param) {
+char lt_unsigned_long_1(Py_ssize_t arraylen, int nosimd, unsigned long *data1, unsigned long param) {
 
 	// array index counter.
 	Py_ssize_t x;
@@ -116,7 +560,7 @@ char lt_unsigned_char_1(Py_ssize_t arraylen, unsigned char *data1, unsigned char
 
 
 // param_num_arr
-char lt_unsigned_char_3(Py_ssize_t arraylen, unsigned char param, unsigned char *data2) {
+char lt_unsigned_long_3(Py_ssize_t arraylen, int nosimd, unsigned long param, unsigned long *data2) {
 
 	// array index counter.
 	Py_ssize_t x;
@@ -131,7 +575,7 @@ char lt_unsigned_char_3(Py_ssize_t arraylen, unsigned char param, unsigned char
 
 
 // param_arr_arr
-char lt_unsigned_char_5(Py_ssize_t arraylen, unsigned char *data1, unsigned char *data2) {
+char lt_unsigned_long_5(Py_ssize_t arraylen, int nosimd, unsigned long *data1, unsigned long *data2) {
 
 	// array index counter.
 	Py_ssize_t x;
@@ -153,7 +597,7 @@ char lt_unsigned_char_5(Py_ssize_t arraylen, unsigned char *data1, unsigned char
    param = The parameter to be applied to each array element.
 */
 // param_arr_num
-char lt_signed_short_1(Py_ssize_t arraylen, signed short *data1, signed short param) {
+char lt_signed_long_long_1(Py_ssize_t arraylen, int nosimd, signed long long *data1, signed long long param) {
 
 	// array index counter.
 	Py_ssize_t x;
@@ -168,7 +612,7 @@ char lt_signed_short_1(Py_ssize_t arraylen, signed short *data1, signed short pa
 
 
 // param_num_arr
-char lt_signed_short_3(Py_ssize_t arraylen, signed short param, signed short *data2) {
+char lt_signed_long_long_3(Py_ssize_t arraylen, int nosimd, signed long long param, signed long long *data2) {
 
 	// array index counter.
 	Py_ssize_t x;
@@ -183,7 +627,7 @@ char lt_signed_short_3(Py_ssize_t arraylen, signed short param, signed short *da
 
 
 // param_arr_arr
-char lt_signed_short_5(Py_ssize_t arraylen, signed short *data1, signed short *data2) {
+char lt_signed_long_long_5(Py_ssize_t arraylen, int nosimd, signed long long *data1, signed long long *data2) {
 
 	// array index counter.
 	Py_ssize_t x;
@@ -205,7 +649,7 @@ char lt_signed_short_5(Py_ssize_t arraylen, signed short *data1, signed short *d
    param = The parameter to be applied to each array element.
 */
 // param_arr_num
-char lt_unsigned_short_1(Py_ssize_t arraylen, unsigned short *data1, unsigned short param) {
+char lt_unsigned_long_long_1(Py_ssize_t arraylen, int nosimd, unsigned long long *data1, unsigned long long param) {
 
 	// array index counter.
 	Py_ssize_t x;
@@ -220,7 +664,7 @@ char lt_unsigned_short_1(Py_ssize_t arraylen, unsigned short *data1, unsigned sh
 
 
 // param_num_arr
-char lt_unsigned_short_3(Py_ssize_t arraylen, unsigned short param, unsigned short *data2) {
+char lt_unsigned_long_long_3(Py_ssize_t arraylen, int nosimd, unsigned long long param, unsigned long long *data2) {
 
 	// array index counter.
 	Py_ssize_t x;
@@ -235,7 +679,7 @@ char lt_unsigned_short_3(Py_ssize_t arraylen, unsigned short param, unsigned sho
 
 
 // param_arr_arr
-char lt_unsigned_short_5(Py_ssize_t arraylen, unsigned short *data1, unsigned short *data2) {
+char lt_unsigned_long_long_5(Py_ssize_t arraylen, int nosimd, unsigned long long *data1, unsigned long long *data2) {
 
 	// array index counter.
 	Py_ssize_t x;
@@ -257,11 +701,18 @@ char lt_unsigned_short_5(Py_ssize_t arraylen, unsigned short *data1, unsigned sh
    param = The parameter to be applied to each array element.
 */
 // param_arr_num
-char lt_signed_int_1(Py_ssize_t arraylen, signed int *data1, signed int param) {
+char lt_float_1(Py_ssize_t arraylen, int nosimd, float *data1, float param) {
 
 	// array index counter.
 	Py_ssize_t x;
 
+#ifdef AF_HASSIMD
+	// SIMD version.
+	if (!nosimd && (arraylen >= (FLOATSIMDSIZE * 2))) {
+		return lt_float_1_simd(arraylen, data1, param);
+	}
+#endif
+
 	for(x = 0; x < arraylen; x++) {
 		if (!(data1[x] < param)) { return 0; }
 	}
@@ -272,11 +723,18 @@ char lt_signed_int_1(Py_ssize_t arraylen, signed int *data1, signed int param) {
 
 
 // param_num_arr
-char lt_signed_int_3(Py_ssize_t arraylen, signed int param, signed int *data2) {
+char lt_float_3(Py_ssize_t arraylen, int nosimd, float param, float *data2) {
 
 	// array index counter.
 	Py_ssize_t x;
 
+#ifdef AF_HASSIMD
+	// SIMD version.
+	if (!nosimd && (arraylen >= (FLOATSIMDSIZE * 2))) {
+		return lt_float_3_simd(arraylen, param, data2);
+	}
+#endif
+
 	for(x = 0; x < arraylen; x++) {
 		if (!(param < data2[x])) { return 0; }
 	}
@@ -287,11 +745,18 @@ char lt_signed_int_3(Py_ssize_t arraylen, signed int param, signed int *data2) {
 
 
 // param_arr_arr
-char lt_signed_int_5(Py_ssize_t arraylen, signed int *data1, signed int *data2) {
+char lt_float_5(Py_ssize_t arraylen, int nosimd, float *data1, float *data2) {
 
 	// array index counter.
 	Py_ssize_t x;
 
+#ifdef AF_HASSIMD
+	// SIMD version.
+	if (!nosimd && (arraylen >= (FLOATSIMDSIZE * 2))) {
+		return lt_float_5_simd(arraylen, data1, data2);
+	}
+#endif
+
 	for(x = 0; x < arraylen; x++) {
 		if (!(data1[x] < data2[x])) { return 0; }
 	}
@@ -309,11 +774,18 @@ char lt_signed_int_5(Py_ssize_t arraylen, signed int *data1, signed int *data2)
    param = The parameter to be applied to each array element.
 */
 // param_arr_num
-char lt_unsigned_int_1(Py_ssize_t arraylen, unsigned int *data1, unsigned int param) {
+char lt_double_1(Py_ssize_t arraylen, int nosimd, double *data1, double param) {
 
 	// array index counter.
 	Py_ssize_t x;
 
+#ifdef AF_HASSIMD
+	// SIMD version.
+	if (!nosimd && (arraylen >= (DOUBLESIMDSIZE * 2))) {
+		return lt_double_1_simd(arraylen, data1, param);
+	}
+#endif
+
 	for(x = 0; x < arraylen; x++) {
 		if (!(data1[x] < param)) { return 0; }
 	}
@@ -324,11 +796,18 @@ char lt_unsigned_int_1(Py_ssize_t arraylen, unsigned int *data1, unsigned int pa
 
 
 // param_num_arr
-char lt_unsigned_int_3(Py_ssize_t arraylen, unsigned int param, unsigned int *data2) {
+char lt_double_3(Py_ssize_t arraylen, int nosimd, double param, double *data2) {
 
 	// array index counter.
 	Py_ssize_t x;
 
+#ifdef AF_HASSIMD
+	// SIMD version.
+	if (!nosimd && (arraylen >= (DOUBLESIMDSIZE * 2))) {
+		return lt_double_3_simd(arraylen, param, data2);
+	}
+#endif
+
 	for(x = 0; x < arraylen; x++) {
 		if (!(param < data2[x])) { return 0; }
 	}
@@ -339,322 +818,17 @@ char lt_unsigned_int_3(Py_ssize_t arraylen, unsigned int param, unsigned int *da
 
 
 // param_arr_arr
-char lt_unsigned_int_5(Py_ssize_t arraylen, unsigned int *data1, unsigned int *data2) {
+char lt_double_5(Py_ssize_t arraylen, int nosimd, double *data1, double *data2) {
 
 	// array index counter.
 	Py_ssize_t x;
 
-	for(x = 0; x < arraylen; x++) {
-		if (!(data1[x] < data2[x])) { return 0; }
+#ifdef AF_HASSIMD
+	// SIMD version.
+	if (!nosimd && (arraylen >= (DOUBLESIMDSIZE * 2))) {
+		return lt_double_5_simd(arraylen, data1, data2);
 	}
-
-	return 1;
-
-}
-
-
-/*--------------------------------------------------------------------------- */
-/* The following series of functions reflect the different parameter options possible.
-   arraylen = The length of the data arrays.
-   data1 = The first data array.
-   data2 = The second data array.
-   param = The parameter to be applied to each array element.
-*/
-// param_arr_num
-char lt_signed_long_1(Py_ssize_t arraylen, signed long *data1, signed long param) {
-
-	// array index counter.
-	Py_ssize_t x;
-
-	for(x = 0; x < arraylen; x++) {
-		if (!(data1[x] < param)) { return 0; }
-	}
-
-	return 1;
-
-}
-
-
-// param_num_arr
-char lt_signed_long_3(Py_ssize_t arraylen, signed long param, signed long *data2) {
-
-	// array index counter.
-	Py_ssize_t x;
-
-	for(x = 0; x < arraylen; x++) {
-		if (!(param < data2[x])) { return 0; }
-	}
-
-	return 1;
-
-}
-
-
-// param_arr_arr
-char lt_signed_long_5(Py_ssize_t arraylen, signed long *data1, signed long *data2) {
-
-	// array index counter.
-	Py_ssize_t x;
-
-	for(x = 0; x < arraylen; x++) {
-		if (!(data1[x] < data2[x])) { return 0; }
-	}
-
-	return 1;
-
-}
-
-
-/*--------------------------------------------------------------------------- */
-/* The following series of functions reflect the different parameter options possible.
-   arraylen = The length of the data arrays.
-   data1 = The first data array.
-   data2 = The second data array.
-   param = The parameter to be applied to each array element.
-*/
-// param_arr_num
-char lt_unsigned_long_1(Py_ssize_t arraylen, unsigned long *data1, unsigned long param) {
-
-	// array index counter.
-	Py_ssize_t x;
-
-	for(x = 0; x < arraylen; x++) {
-		if (!(data1[x] < param)) { return 0; }
-	}
-
-	return 1;
-
-}
-
-
-// param_num_arr
-char lt_unsigned_long_3(Py_ssize_t arraylen, unsigned long param, unsigned long *data2) {
-
-	// array index counter.
-	Py_ssize_t x;
-
-	for(x = 0; x < arraylen; x++) {
-		if (!(param < data2[x])) { return 0; }
-	}
-
-	return 1;
-
-}
-
-
-// param_arr_arr
-char lt_unsigned_long_5(Py_ssize_t arraylen, unsigned long *data1, unsigned long *data2) {
-
-	// array index counter.
-	Py_ssize_t x;
-
-	for(x = 0; x < arraylen; x++) {
-		if (!(data1[x] < data2[x])) { return 0; }
-	}
-
-	return 1;
-
-}
-
-
-/*--------------------------------------------------------------------------- */
-/* The following series of functions reflect the different parameter options possible.
-   arraylen = The length of the data arrays.
-   data1 = The first data array.
-   data2 = The second data array.
-   param = The parameter to be applied to each array element.
-*/
-// param_arr_num
-char lt_signed_long_long_1(Py_ssize_t arraylen, signed long long *data1, signed long long param) {
-
-	// array index counter.
-	Py_ssize_t x;
-
-	for(x = 0; x < arraylen; x++) {
-		if (!(data1[x] < param)) { return 0; }
-	}
-
-	return 1;
-
-}
-
-
-// param_num_arr
-char lt_signed_long_long_3(Py_ssize_t arraylen, signed long long param, signed long long *data2) {
-
-	// array index counter.
-	Py_ssize_t x;
-
-	for(x = 0; x < arraylen; x++) {
-		if (!(param < data2[x])) { return 0; }
-	}
-
-	return 1;
-
-}
-
-
-// param_arr_arr
-char lt_signed_long_long_5(Py_ssize_t arraylen, signed long long *data1, signed long long *data2) {
-
-	// array index counter.
-	Py_ssize_t x;
-
-	for(x = 0; x < arraylen; x++) {
-		if (!(data1[x] < data2[x])) { return 0; }
-	}
-
-	return 1;
-
-}
-
-
-/*--------------------------------------------------------------------------- */
-/* The following series of functions reflect the different parameter options possible.
-   arraylen = The length of the data arrays.
-   data1 = The first data array.
-   data2 = The second data array.
-   param = The parameter to be applied to each array element.
-*/
-// param_arr_num
-char lt_unsigned_long_long_1(Py_ssize_t arraylen, unsigned long long *data1, unsigned long long param) {
-
-	// array index counter.
-	Py_ssize_t x;
-
-	for(x = 0; x < arraylen; x++) {
-		if (!(data1[x] < param)) { return 0; }
-	}
-
-	return 1;
-
-}
-
-
-// param_num_arr
-char lt_unsigned_long_long_3(Py_ssize_t arraylen, unsigned long long param, unsigned long long *data2) {
-
-	// array index counter.
-	Py_ssize_t x;
-
-	for(x = 0; x < arraylen; x++) {
-		if (!(param < data2[x])) { return 0; }
-	}
-
-	return 1;
-
-}
-
-
-// param_arr_arr
-char lt_unsigned_long_long_5(Py_ssize_t arraylen, unsigned long long *data1, unsigned long long *data2) {
-
-	// array index counter.
-	Py_ssize_t x;
-
-	for(x = 0; x < arraylen; x++) {
-		if (!(data1[x] < data2[x])) { return 0; }
-	}
-
-	return 1;
-
-}
-
-
-/*--------------------------------------------------------------------------- */
-/* The following series of functions reflect the different parameter options possible.
-   arraylen = The length of the data arrays.
-   data1 = The first data array.
-   data2 = The second data array.
-   param = The parameter to be applied to each array element.
-*/
-// param_arr_num
-char lt_float_1(Py_ssize_t arraylen, float *data1, float param) {
-
-	// array index counter.
-	Py_ssize_t x;
-
-	for(x = 0; x < arraylen; x++) {
-		if (!(data1[x] < param)) { return 0; }
-	}
-
-	return 1;
-
-}
-
-
-// param_num_arr
-char lt_float_3(Py_ssize_t arraylen, float param, float *data2) {
-
-	// array index counter.
-	Py_ssize_t x;
-
-	for(x = 0; x < arraylen; x++) {
-		if (!(param < data2[x])) { return 0; }
-	}
-
-	return 1;
-
-}
-
-
-// param_arr_arr
-char lt_float_5(Py_ssize_t arraylen, float *data1, float *data2) {
-
-	// array index counter.
-	Py_ssize_t x;
-
-	for(x = 0; x < arraylen; x++) {
-		if (!(data1[x] < data2[x])) { return 0; }
-	}
-
-	return 1;
-
-}
-
-
-/*--------------------------------------------------------------------------- */
-/* The following series of functions reflect the different parameter options possible.
-   arraylen = The length of the data arrays.
-   data1 = The first data array.
-   data2 = The second data array.
-   param = The parameter to be applied to each array element.
-*/
-// param_arr_num
-char lt_double_1(Py_ssize_t arraylen, double *data1, double param) {
-
-	// array index counter.
-	Py_ssize_t x;
-
-	for(x = 0; x < arraylen; x++) {
-		if (!(data1[x] < param)) { return 0; }
-	}
-
-	return 1;
-
-}
-
-
-// param_num_arr
-char lt_double_3(Py_ssize_t arraylen, double param, double *data2) {
-
-	// array index counter.
-	Py_ssize_t x;
-
-	for(x = 0; x < arraylen; x++) {
-		if (!(param < data2[x])) { return 0; }
-	}
-
-	return 1;
-
-}
-
-
-// param_arr_arr
-char lt_double_5(Py_ssize_t arraylen, double *data1, double *data2) {
-
-	// array index counter.
-	Py_ssize_t x;
+#endif
 
 	for(x = 0; x < arraylen; x++) {
 		if (!(data1[x] < data2[x])) { return 0; }
@@ -696,15 +870,15 @@ static PyObject *py_lt(PyObject *self, PyObject *args, PyObject *keywds) {
 		case 'b' : {
 			switch (arraydata.paramcat) {
 				case param_arr_num : {
-					resultcode = lt_signed_char_1(arraydata.arraylength, arraydata.array1.b, arraydata.param.b);
+					resultcode = lt_signed_char_1(arraydata.arraylength, arraydata.nosimd, arraydata.array1.b, arraydata.param.b);
 					break;
 				}
 				case param_num_arr : {
-					resultcode = lt_signed_char_3(arraydata.arraylength, arraydata.param.b, arraydata.array2.b);
+					resultcode = lt_signed_char_3(arraydata.arraylength, arraydata.nosimd, arraydata.param.b, arraydata.array2.b);
 					break;
 				}
 				case param_arr_arr : {
-					resultcode = lt_signed_char_5(arraydata.arraylength, arraydata.array1.b, arraydata.array2.b);
+					resultcode = lt_signed_char_5(arraydata.arraylength, arraydata.nosimd, arraydata.array1.b, arraydata.array2.b);
 					break;
 				}
 			}
@@ -715,15 +889,15 @@ static PyObject *py_lt(PyObject *self, PyObject *args, PyObject *keywds) {
 		case 'B' : {
 			switch (arraydata.paramcat) {
 				case param_arr_num : {
-					resultcode = lt_unsigned_char_1(arraydata.arraylength, arraydata.array1.B, arraydata.param.B);
+					resultcode = lt_unsigned_char_1(arraydata.arraylength, arraydata.nosimd, arraydata.array1.B, arraydata.param.B);
 					break;
 				}
 				case param_num_arr : {
-					resultcode = lt_unsigned_char_3(arraydata.arraylength, arraydata.param.B, arraydata.array2.B);
+					resultcode = lt_unsigned_char_3(arraydata.arraylength, arraydata.nosimd, arraydata.param.B, arraydata.array2.B);
 					break;
 				}
 				case param_arr_arr : {
-					resultcode = lt_unsigned_char_5(arraydata.arraylength, arraydata.array1.B, arraydata.array2.B);
+					resultcode = lt_unsigned_char_5(arraydata.arraylength, arraydata.nosimd, arraydata.array1.B, arraydata.array2.B);
 					break;
 				}
 			}
@@ -734,15 +908,15 @@ static PyObject *py_lt(PyObject *self, PyObject *args, PyObject *keywds) {
 		case 'h' : {
 			switch (arraydata.paramcat) {
 				case param_arr_num : {
-					resultcode = lt_signed_short_1(arraydata.arraylength, arraydata.array1.h, arraydata.param.h);
+					resultcode = lt_signed_short_1(arraydata.arraylength, arraydata.nosimd, arraydata.array1.h, arraydata.param.h);
 					break;
 				}
 				case param_num_arr : {
-					resultcode = lt_signed_short_3(arraydata.arraylength, arraydata.param.h, arraydata.array2.h);
+					resultcode = lt_signed_short_3(arraydata.arraylength, arraydata.nosimd, arraydata.param.h, arraydata.array2.h);
 					break;
 				}
 				case param_arr_arr : {
-					resultcode = lt_signed_short_5(arraydata.arraylength, arraydata.array1.h, arraydata.array2.h);
+					resultcode = lt_signed_short_5(arraydata.arraylength, arraydata.nosimd, arraydata.array1.h, arraydata.array2.h);
 					break;
 				}
 			}
@@ -753,15 +927,15 @@ static PyObject *py_lt(PyObject *self, PyObject *args, PyObject *keywds) {
 		case 'H' : {
 			switch (arraydata.paramcat) {
 				case param_arr_num : {
-					resultcode = lt_unsigned_short_1(arraydata.arraylength, arraydata.array1.H, arraydata.param.H);
+					resultcode = lt_unsigned_short_1(arraydata.arraylength, arraydata.nosimd, arraydata.array1.H, arraydata.param.H);
 					break;
 				}
 				case param_num_arr : {
-					resultcode = lt_unsigned_short_3(arraydata.arraylength, arraydata.param.H, arraydata.array2.H);
+					resultcode = lt_unsigned_short_3(arraydata.arraylength, arraydata.nosimd, arraydata.param.H, arraydata.array2.H);
 					break;
 				}
 				case param_arr_arr : {
-					resultcode = lt_unsigned_short_5(arraydata.arraylength, arraydata.array1.H, arraydata.array2.H);
+					resultcode = lt_unsigned_short_5(arraydata.arraylength, arraydata.nosimd, arraydata.array1.H, arraydata.array2.H);
 					break;
 				}
 			}
@@ -772,15 +946,15 @@ static PyObject *py_lt(PyObject *self, PyObject *args, PyObject *keywds) {
 		case 'i' : {
 			switch (arraydata.paramcat) {
 				case param_arr_num : {
-					resultcode = lt_signed_int_1(arraydata.arraylength, arraydata.array1.i, arraydata.param.i);
+					resultcode = lt_signed_int_1(arraydata.arraylength, arraydata.nosimd, arraydata.array1.i, arraydata.param.i);
 					break;
 				}
 				case param_num_arr : {
-					resultcode = lt_signed_int_3(arraydata.arraylength, arraydata.param.i, arraydata.array2.i);
+					resultcode = lt_signed_int_3(arraydata.arraylength, arraydata.nosimd, arraydata.param.i, arraydata.array2.i);
 					break;
 				}
 				case param_arr_arr : {
-					resultcode = lt_signed_int_5(arraydata.arraylength, arraydata.array1.i, arraydata.array2.i);
+					resultcode = lt_signed_int_5(arraydata.arraylength, arraydata.nosimd, arraydata.array1.i, arraydata.array2.i);
 					break;
 				}
 			}
@@ -791,15 +965,15 @@ static PyObject *py_lt(PyObject *self, PyObject *args, PyObject *keywds) {
 		case 'I' : {
 			switch (arraydata.paramcat) {
 				case param_arr_num : {
-					resultcode = lt_unsigned_int_1(arraydata.arraylength, arraydata.array1.I, arraydata.param.I);
+					resultcode = lt_unsigned_int_1(arraydata.arraylength, arraydata.nosimd, arraydata.array1.I, arraydata.param.I);
 					break;
 				}
 				case param_num_arr : {
-					resultcode = lt_unsigned_int_3(arraydata.arraylength, arraydata.param.I, arraydata.array2.I);
+					resultcode = lt_unsigned_int_3(arraydata.arraylength, arraydata.nosimd, arraydata.param.I, arraydata.array2.I);
 					break;
 				}
 				case param_arr_arr : {
-					resultcode = lt_unsigned_int_5(arraydata.arraylength, arraydata.array1.I, arraydata.array2.I);
+					resultcode = lt_unsigned_int_5(arraydata.arraylength, arraydata.nosimd, arraydata.array1.I, arraydata.array2.I);
 					break;
 				}
 			}
@@ -810,15 +984,15 @@ static PyObject *py_lt(PyObject *self, PyObject *args, PyObject *keywds) {
 		case 'l' : {
 			switch (arraydata.paramcat) {
 				case param_arr_num : {
-					resultcode = lt_signed_long_1(arraydata.arraylength, arraydata.array1.l, arraydata.param.l);
+					resultcode = lt_signed_long_1(arraydata.arraylength, arraydata.nosimd, arraydata.array1.l, arraydata.param.l);
 					break;
 				}
 				case param_num_arr : {
-					resultcode = lt_signed_long_3(arraydata.arraylength, arraydata.param.l, arraydata.array2.l);
+					resultcode = lt_signed_long_3(arraydata.arraylength, arraydata.nosimd, arraydata.param.l, arraydata.array2.l);
 					break;
 				}
 				case param_arr_arr : {
-					resultcode = lt_signed_long_5(arraydata.arraylength, arraydata.array1.l, arraydata.array2.l);
+					resultcode = lt_signed_long_5(arraydata.arraylength, arraydata.nosimd, arraydata.array1.l, arraydata.array2.l);
 					break;
 				}
 			}
@@ -829,15 +1003,15 @@ static PyObject *py_lt(PyObject *self, PyObject *args, PyObject *keywds) {
 		case 'L' : {
 			switch (arraydata.paramcat) {
 				case param_arr_num : {
-					resultcode = lt_unsigned_long_1(arraydata.arraylength, arraydata.array1.L, arraydata.param.L);
+					resultcode = lt_unsigned_long_1(arraydata.arraylength, arraydata.nosimd, arraydata.array1.L, arraydata.param.L);
 					break;
 				}
 				case param_num_arr : {
-					resultcode = lt_unsigned_long_3(arraydata.arraylength, arraydata.param.L, arraydata.array2.L);
+					resultcode = lt_unsigned_long_3(arraydata.arraylength, arraydata.nosimd, arraydata.param.L, arraydata.array2.L);
 					break;
 				}
 				case param_arr_arr : {
-					resultcode = lt_unsigned_long_5(arraydata.arraylength, arraydata.array1.L, arraydata.array2.L);
+					resultcode = lt_unsigned_long_5(arraydata.arraylength, arraydata.nosimd, arraydata.array1.L, arraydata.array2.L);
 					break;
 				}
 			}
@@ -848,15 +1022,15 @@ static PyObject *py_lt(PyObject *self, PyObject *args, PyObject *keywds) {
 		case 'q' : {
 			switch (arraydata.paramcat) {
 				case param_arr_num : {
-					resultcode = lt_signed_long_long_1(arraydata.arraylength, arraydata.array1.q, arraydata.param.q);
+					resultcode = lt_signed_long_long_1(arraydata.arraylength, arraydata.nosimd, arraydata.array1.q, arraydata.param.q);
 					break;
 				}
 				case param_num_arr : {
-					resultcode = lt_signed_long_long_3(arraydata.arraylength, arraydata.param.q, arraydata.array2.q);
+					resultcode = lt_signed_long_long_3(arraydata.arraylength, arraydata.nosimd, arraydata.param.q, arraydata.array2.q);
 					break;
 				}
 				case param_arr_arr : {
-					resultcode = lt_signed_long_long_5(arraydata.arraylength, arraydata.array1.q, arraydata.array2.q);
+					resultcode = lt_signed_long_long_5(arraydata.arraylength, arraydata.nosimd, arraydata.array1.q, arraydata.array2.q);
 					break;
 				}
 			}
@@ -867,15 +1041,15 @@ static PyObject *py_lt(PyObject *self, PyObject *args, PyObject *keywds) {
 		case 'Q' : {
 			switch (arraydata.paramcat) {
 				case param_arr_num : {
-					resultcode = lt_unsigned_long_long_1(arraydata.arraylength, arraydata.array1.Q, arraydata.param.Q);
+					resultcode = lt_unsigned_long_long_1(arraydata.arraylength, arraydata.nosimd, arraydata.array1.Q, arraydata.param.Q);
 					break;
 				}
 				case param_num_arr : {
-					resultcode = lt_unsigned_long_long_3(arraydata.arraylength, arraydata.param.Q, arraydata.array2.Q);
+					resultcode = lt_unsigned_long_long_3(arraydata.arraylength, arraydata.nosimd, arraydata.param.Q, arraydata.array2.Q);
 					break;
 				}
 				case param_arr_arr : {
-					resultcode = lt_unsigned_long_long_5(arraydata.arraylength, arraydata.array1.Q, arraydata.array2.Q);
+					resultcode = lt_unsigned_long_long_5(arraydata.arraylength, arraydata.nosimd, arraydata.array1.Q, arraydata.array2.Q);
 					break;
 				}
 			}
@@ -886,15 +1060,15 @@ static PyObject *py_lt(PyObject *self, PyObject *args, PyObject *keywds) {
 		case 'f' : {
 			switch (arraydata.paramcat) {
 				case param_arr_num : {
-					resultcode = lt_float_1(arraydata.arraylength, arraydata.array1.f, arraydata.param.f);
+					resultcode = lt_float_1(arraydata.arraylength, arraydata.nosimd, arraydata.array1.f, arraydata.param.f);
 					break;
 				}
 				case param_num_arr : {
-					resultcode = lt_float_3(arraydata.arraylength, arraydata.param.f, arraydata.array2.f);
+					resultcode = lt_float_3(arraydata.arraylength, arraydata.nosimd, arraydata.param.f, arraydata.array2.f);
 					break;
 				}
 				case param_arr_arr : {
-					resultcode = lt_float_5(arraydata.arraylength, arraydata.array1.f, arraydata.array2.f);
+					resultcode = lt_float_5(arraydata.arraylength, arraydata.nosimd, arraydata.array1.f, arraydata.array2.f);
 					break;
 				}
 			}
@@ -905,15 +1079,15 @@ static PyObject *py_lt(PyObject *self, PyObject *args, PyObject *keywds) {
 		case 'd' : {
 			switch (arraydata.paramcat) {
 				case param_arr_num : {
-					resultcode = lt_double_1(arraydata.arraylength, arraydata.array1.d, arraydata.param.d);
+					resultcode = lt_double_1(arraydata.arraylength, arraydata.nosimd, arraydata.array1.d, arraydata.param.d);
 					break;
 				}
 				case param_num_arr : {
-					resultcode = lt_double_3(arraydata.arraylength, arraydata.param.d, arraydata.array2.d);
+					resultcode = lt_double_3(arraydata.arraylength, arraydata.nosimd, arraydata.param.d, arraydata.array2.d);
 					break;
 				}
 				case param_arr_arr : {
-					resultcode = lt_double_5(arraydata.arraylength, arraydata.array1.d, arraydata.array2.d);
+					resultcode = lt_double_5(arraydata.arraylength, arraydata.nosimd, arraydata.array1.d, arraydata.array2.d);
 					break;
 				}
 			}
@@ -965,6 +1139,7 @@ Call formats: \n\
   result = lt(param, array1) \n\
   result = lt(array1, array2) \n\
   result = lt(array1, param, maxlen=y) \n\
+  result = lt(array1, param, nosimd=False) \n\
 \n\
 * array1 - The first input data array to be examined. If no output  \n\
   array is provided the results will overwrite the input data.  \n\
@@ -975,6 +1150,8 @@ Call formats: \n\
   positive integer. If a zero or negative length, or a value which is  \n\
   greater than the actual length of the array is specified, this  \n\
   parameter is ignored.  \n\
+* nosimd - If True, SIMD acceleration is disabled if present.  \n\
+  The default is False (SIMD acceleration is enabled if present). \n\
 * result - A boolean value corresponding to the result of all the \n\
   comparison operations. If all comparison operations result in true, \n\
   the return value will be true. If any of them result in false, the \n\
