@@ -39,6 +39,8 @@
 
 #include "arrayparams_two.h"
 
+
+
 /*--------------------------------------------------------------------------- */
 
 /*--------------------------------------------------------------------------- */
@@ -2124,7 +2126,7 @@ static PyObject *py_mod(PyObject *self, PyObject *args, PyObject *keywds) {
 
 
 	// Get the parameters passed from Python.
-	arraydata = getparams_two(self, args, keywds, 1, "mod");
+	arraydata = getparams_two(self, args, keywds, 1, 0, "mod");
 
 	// If there was an error, we count on the parameter parsing function to 
 	// release the buffers if this was necessary.
@@ -2582,7 +2584,7 @@ Call formats: \n\
   parameter is ignored.  \n\
 * matherrors - If true, arithmetic error checking is disabled. The  \n\
   default is false. \n\
-\n");
+");
 
 /*--------------------------------------------------------------------------- */
 
