@@ -39,6 +39,8 @@
 
 #include "arrayparams_two.h"
 
+
+
 /*--------------------------------------------------------------------------- */
 
 /*--------------------------------------------------------------------------- */
@@ -1729,7 +1731,7 @@ static PyObject *py_truediv(PyObject *self, PyObject *args, PyObject *keywds) {
 
 
 	// Get the parameters passed from Python.
-	arraydata = getparams_two(self, args, keywds, 1, "truediv");
+	arraydata = getparams_two(self, args, keywds, 1, 0, "truediv");
 
 	// If there was an error, we count on the parameter parsing function to 
 	// release the buffers if this was necessary.
@@ -2187,7 +2189,7 @@ Call formats: \n\
   parameter is ignored.  \n\
 * matherrors - If true, arithmetic error checking is disabled. The  \n\
   default is false. \n\
-\n");
+");
 
 /*--------------------------------------------------------------------------- */
 
